/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.util;

import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.extension.data.ITransformationContext;
import org.fortiss.tooling.kernel.extension.data.TransformationProviderChain;
import org.fortiss.tooling.kernel.extension.exception.ChainTransformationFailedException;
import org.fortiss.tooling.kernel.service.ITransformationService;

/**
 * Utility methods for the {@link ITransformationService}.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED Hash:
 */
public final class TransformationUtil {
	/**
	 * Searches a transformation chain for the given model element and the
	 * target class and returns the transformation result.
	 */
	@SuppressWarnings("unchecked")
	public static <T extends Object> T createTransformedObjectFor(
			EObject modelElement, Class<T> targetClass,
			ITransformationContext context)
			throws ChainTransformationFailedException {
		List<TransformationProviderChain> chainList = ITransformationService.INSTANCE
				.getTransformationProviderChain(modelElement.getClass(),
						targetClass, context);
		if (!chainList.isEmpty()) {
			return (T) chainList.get(0).transform(modelElement, context);
		}
		return null;
	}

}
